@@ -25,7 +25,7 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '5.1.0'
+version = '5.2.0'
 nightbuild = ''
 
 
@@ -79,11 +79,14 @@ main={
     'mzDigits': 4,
     'intDigits': 0,
     'ppmDigits': 1,
+    'chargeDigits': 2,
     'dataPrecision': 32,
     'lastDir': '',
     'lastSeqDir': '',
     'errorUnits': 'Da',
     'printQuality': 5,
+    'useServer': 1,
+    'serverPort': 65456,
     'reverseScrolling': 0,
     'macListCtrlGeneric': 1,
     'peaklistColumns': ['mz', 'int', 'rel', 'sn', 'z', 'fwhm', 'resol'],
@@ -316,6 +319,8 @@ massCalculator={
 massfilter={}
 
 massToFormula={
+    'countLimit': 1000,
+    'massLimit': 3000,
     'charge': 1,
     'ionization': 'H',
     'tolerance': 1.,
@@ -324,7 +329,6 @@ massToFormula={
     'formulaMax': '',
     'autoCHNO': 1,
     'checkPattern': 1,
-    'limit': 1000,
     'rules': ['HC','NOPSC','NOPS','RDBE', 'RDBEInt'],
     'HCMin': 0.1,
     'HCMax': 3,
@@ -866,10 +870,13 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="mzDigits" value="%d" type="int" />\n' % (main['mzDigits'])
     buff += '    <param name="intDigits" value="%d" type="int" />\n' % (main['intDigits'])
     buff += '    <param name="ppmDigits" value="%d" type="int" />\n' % (main['ppmDigits'])
+    buff += '    <param name="chargeDigits" value="%d" type="int" />\n' % (main['chargeDigits'])
     buff += '    <param name="lastDir" value="%s" type="unicode" />\n' % (_escape(main['lastDir']))
     buff += '    <param name="lastSeqDir" value="%s" type="unicode" />\n' % (_escape(main['lastSeqDir']))
     buff += '    <param name="errorUnits" value="%s" type="str" />\n' % (main['errorUnits'])
     buff += '    <param name="printQuality" value="%d" type="int" />\n' % (main['printQuality'])
+    buff += '    <param name="useServer" value="%d" type="int" />\n' % (bool(main['useServer']))
+    buff += '    <param name="serverPort" value="%d" type="int" />\n' % (main['serverPort'])
     buff += '    <param name="donate" value="%s" type="str" />\n' % (main['donate'])
     buff += '    <param name="updatesEnabled" value="%d" type="int" />\n' % (bool(main['updatesEnabled']))
     buff += '    <param name="updatesChecked" value="%s" type="str" />\n' % (main['updatesChecked'])
@@ -1065,6 +1072,8 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     
     # mass to formula
     buff += '  <massToFormula>\n'
+    buff += '    <param name="countLimit" value="%d" type="int" />\n' % (massToFormula['countLimit'])
+    buff += '    <param name="massLimit" value="%d" type="int" />\n' % (massToFormula['massLimit'])
     buff += '    <param name="charge" value="%d" type="int" />\n' % (massToFormula['charge'])
     buff += '    <param name="ionization" value="%s" type="str" />\n' % (massToFormula['ionization'])
     buff += '    <param name="tolerance" value="%f" type="float" />\n' % (massToFormula['tolerance'])
@@ -1073,7 +1082,6 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="formulaMax" value="%s" type="str" />\n' % (massToFormula['formulaMax'])
     buff += '    <param name="autoCHNO" value="%d" type="int" />\n' % (bool(massToFormula['autoCHNO']))
     buff += '    <param name="checkPattern" value="%d" type="int" />\n' % (bool(massToFormula['checkPattern']))
-    buff += '    <param name="limit" value="%d" type="int" />\n' % (massToFormula['limit'])
     buff += '    <param name="rules" value="%s" type="str" />\n' % (';'.join(massToFormula['rules']))
     buff += '    <param name="HCMin" value="%f" type="float" />\n' % (massToFormula['HCMin'])
     buff += '    <param name="HCMax" value="%f" type="float" />\n' % (massToFormula['HCMax'])
