@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -57,7 +57,6 @@ class dlgClipboardEditor(wx.Dialog):
         
         # make elements
         self.data_value = wx.TextCtrl(self, -1, "Reading data...", size=(250,300), style=wx.TE_MULTILINE)
-        self.data_value.Bind(wx.EVT_TEXT_ENTER, self.onOK)
         self.data_value.SetFont(wx.SMALL_FONT)
         
         note_label = wx.StaticText(self, -1, "Please edit your clipboard data to consist\nof m/z and intensity columns only.\nRemove all non-digit characters.", style=wx.ALIGN_CENTER)
@@ -84,7 +83,10 @@ class dlgClipboardEditor(wx.Dialog):
     def onOK(self, evt):
         """Get name."""
         
+        # get data
         self.data = self.data_value.GetValue()
+        
+        # close dialog
         if self.data:
             self.EndModal(wx.ID_OK)
         else:
