@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -29,7 +29,7 @@ import mspy
 # ---------------------
 
 class dlgSelectScans(wx.Dialog):
-    """Select scans from multiscan files"""
+    """Select scans from multiscan files."""
     
     def __init__(self, parent, scans):
         wx.Dialog.__init__(self, parent, -1, "Select Scan", style=wx.DEFAULT_DIALOG_STYLE|wx.STAY_ON_TOP|wx.RESIZE_BORDER)
@@ -72,9 +72,9 @@ class dlgSelectScans(wx.Dialog):
         
         # pack element
         sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.Add(self.scanList, 0, wx.EXPAND|wx.TOP|wx.LEFT|wx.RIGHT, mwx.LISTCTRL_SPACE)
+        sizer.Add(self.scanList, 1, wx.EXPAND|wx.TOP|wx.LEFT|wx.RIGHT, mwx.LISTCTRL_SPACE)
         sizer.AddSpacer(3)
-        sizer.Add(self.chromCanvas, 0, wx.EXPAND|wx.TOP|wx.LEFT|wx.RIGHT, mwx.LISTCTRL_SPACE)
+        sizer.Add(self.chromCanvas, 1, wx.EXPAND|wx.TOP|wx.LEFT|wx.RIGHT, mwx.LISTCTRL_SPACE)
         sizer.Add(buttons, 0, wx.CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
         
         return sizer
@@ -137,6 +137,7 @@ class dlgSelectScans(wx.Dialog):
         self.chromCanvas.setProperties(xLabel='retention time in min.')
         self.chromCanvas.setProperties(yLabel='normalized ion current')
         self.chromCanvas.setProperties(showGrid=True)
+        self.chromCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         self.chromCanvas.setProperties(showLegend=True)
         self.chromCanvas.setProperties(showPosBar=True)
         self.chromCanvas.setProperties(showIntBar=True)
