@@ -100,6 +100,7 @@ ID_viewLabelBgr = wx.NewId()
 ID_viewLabelAngle = wx.NewId()
 ID_viewAllLabels = wx.NewId()
 ID_viewOverlapLabels = wx.NewId()
+ID_viewCheckLimits = wx.NewId()
 ID_viewNotations = wx.NewId()
 ID_viewNotationMarks = wx.NewId()
 ID_viewNotationLabels = wx.NewId()
@@ -113,7 +114,8 @@ ID_viewSpectrumRulerMz = wx.NewId()
 ID_viewSpectrumRulerDist = wx.NewId()
 ID_viewSpectrumRulerPpm = wx.NewId()
 ID_viewSpectrumRulerZ = wx.NewId()
-ID_viewSpectrumRulerMass = wx.NewId()
+ID_viewSpectrumRulerCursorMass = wx.NewId()
+ID_viewSpectrumRulerParentMass = wx.NewId()
 ID_viewSpectrumRulerArea = wx.NewId()
 
 ID_viewPeaklistColumnMz = wx.NewId()
@@ -182,11 +184,11 @@ ID_sequenceMatchesCalibrateBy = wx.NewId()
 ID_toolsProcessing = wx.NewId()
 ID_toolsCalibration = wx.NewId()
 ID_toolsSequence = wx.NewId()
+ID_toolsRuler = wx.NewId()
 ID_toolsLabelPeak = wx.NewId()
 ID_toolsLabelPoint = wx.NewId()
 ID_toolsLabelEnvelope = wx.NewId()
 ID_toolsDeleteLabel = wx.NewId()
-ID_toolsMeasure = wx.NewId()
 ID_toolsOffset = wx.NewId()
 ID_toolsPeriodicTable = wx.NewId()
 ID_toolsMassCalculator = wx.NewId()
@@ -205,11 +207,11 @@ ID_toolsDocumentReport = wx.NewId()
 ID_toolsDocumentExport = wx.NewId()
 
 HK_toolsCalibration = '\tCtrl+R'
+HK_toolsRuler = '\tShift+Ctrl+H'
 HK_toolsLabelPeak = '\tShift+Ctrl+P'
 HK_toolsLabelPoint = '\tShift+Ctrl+I'
 HK_toolsLabelEnvelope = '\tShift+Ctrl+E'
 HK_toolsDeleteLabel = '\tShift+Ctrl+X'
-HK_toolsMeasure = '\tShift+Ctrl+H'
 HK_toolsPeriodicTable = '\tShift+Ctrl+T'
 HK_toolsMassCalculator = '\tShift+Ctrl+M'
 HK_toolsMassToFormula = '\tShift+Ctrl+B'
