@@ -211,16 +211,16 @@ def loadImages():
     lib['spectrumNormalizeOn'] = bottombarsOn.GetSubBitmap(wx.Rect(232, 44, 29, 22))
     lib['spectrumNormalizeOff'] = bottombarsOff.GetSubBitmap(wx.Rect(232, 44, 29, 22))
     
-    lib['spectrumLabelPeakOn'] = bottombarsOn.GetSubBitmap(wx.Rect(0, 66, 29, 22))
-    lib['spectrumLabelPeakOff'] = bottombarsOff.GetSubBitmap(wx.Rect(0, 66, 29, 22))
-    lib['spectrumLabelPointOn'] = bottombarsOn.GetSubBitmap(wx.Rect(29, 66, 29, 22))
-    lib['spectrumLabelPointOff'] = bottombarsOff.GetSubBitmap(wx.Rect(29, 66, 29, 22))
-    lib['spectrumLabelEnvelopeOn'] = bottombarsOn.GetSubBitmap(wx.Rect(58, 66, 29, 22))
-    lib['spectrumLabelEnvelopeOff'] = bottombarsOff.GetSubBitmap(wx.Rect(58, 66, 29, 22))
-    lib['spectrumDeleteLabelOn'] = bottombarsOn.GetSubBitmap(wx.Rect(87, 66, 29, 22))
-    lib['spectrumDeleteLabelOff'] = bottombarsOff.GetSubBitmap(wx.Rect(87, 66, 29, 22))
-    lib['spectrumMeasureOn'] = bottombarsOn.GetSubBitmap(wx.Rect(116, 66, 29, 22))
-    lib['spectrumMeasureOff'] = bottombarsOff.GetSubBitmap(wx.Rect(116, 66, 29, 22))
+    lib['spectrumRulerOn'] = bottombarsOn.GetSubBitmap(wx.Rect(0, 66, 29, 22))
+    lib['spectrumRulerOff'] = bottombarsOff.GetSubBitmap(wx.Rect(0, 66, 29, 22))
+    lib['spectrumLabelPeakOn'] = bottombarsOn.GetSubBitmap(wx.Rect(29, 66, 29, 22))
+    lib['spectrumLabelPeakOff'] = bottombarsOff.GetSubBitmap(wx.Rect(29, 66, 29, 22))
+    lib['spectrumLabelPointOn'] = bottombarsOn.GetSubBitmap(wx.Rect(58, 66, 29, 22))
+    lib['spectrumLabelPointOff'] = bottombarsOff.GetSubBitmap(wx.Rect(58, 66, 29, 22))
+    lib['spectrumLabelEnvelopeOn'] = bottombarsOn.GetSubBitmap(wx.Rect(87, 66, 29, 22))
+    lib['spectrumLabelEnvelopeOff'] = bottombarsOff.GetSubBitmap(wx.Rect(87, 66, 29, 22))
+    lib['spectrumDeleteLabelOn'] = bottombarsOn.GetSubBitmap(wx.Rect(116, 66, 29, 22))
+    lib['spectrumDeleteLabelOff'] = bottombarsOff.GetSubBitmap(wx.Rect(116, 66, 29, 22))
     lib['spectrumOffsetOn'] = bottombarsOn.GetSubBitmap(wx.Rect(145, 66, 29, 22))
     lib['spectrumOffsetOff'] = bottombarsOff.GetSubBitmap(wx.Rect(145, 66, 29, 22))
     
