@@ -96,6 +96,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
         'MALDI-TOF Peptides':{
             'crop':{
@@ -138,6 +147,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
         'MALDI-TOF Proteins 5-20 kDa':{
             'crop':{
@@ -180,6 +198,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
         'MALDI-TOF PSD':{
             'crop':{
@@ -222,6 +249,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
         'MALDI-ICR Peptides':{
             'crop':{
@@ -264,6 +300,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
         'MALDI-ICR Low Mass':{
             'crop':{
@@ -306,6 +351,15 @@ presets = {
                 'groupPeaks': 1,
                 'forceGroupWindow': 0,
             },
+            'batch':{
+                'math': 0,
+                'crop': 0,
+                'baseline': 0,
+                'smoothing': 0,
+                'peakpicking': 0,
+                'deisotoping': 0,
+                'deconvolution': 0,
+            },
         },
     },
     'modifications':{
