@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -73,15 +73,18 @@ class panelAbout(frame):
         version = wx.StaticText(panel, -1, versionLabel, style=wx.ALIGN_CENTRE)
         version.SetFont(wx.SMALL_FONT)
         
-        copyright = wx.StaticText(panel, -1, "(c) 2005-2011 Martin Strohalm")
+        copyright = wx.StaticText(panel, -1, "(c) 2005-2012 Martin Strohalm")
         copyright.SetFont(wx.SMALL_FONT)
         
         homepage_butt = wx.Button(panel, ID_helpHomepage, "Homepage", size=(150, -1))
         homepage_butt.Bind(wx.EVT_BUTTON, self.parent.onLibraryLink)
         
-        donate_butt = wx.Button(panel, ID_helpDonate, "Cite or Donate", size=(150, -1))
+        donate_butt = wx.Button(panel, ID_helpDonate, "Make a Donation", size=(150, -1))
         donate_butt.Bind(wx.EVT_BUTTON, self.parent.onLibraryLink)
         
+        cite_butt = wx.Button(panel, ID_helpCite, "How to Cite", size=(150, -1))
+        cite_butt.Bind(wx.EVT_BUTTON, self.parent.onLibraryLink)
+        
         # pack element
         sizer = wx.BoxSizer(wx.VERTICAL)
         sizer.Add(image, 0, wx.CENTER|wx.ALL, 20)
@@ -93,7 +96,9 @@ class panelAbout(frame):
         sizer.AddSpacer(20)
         sizer.Add(homepage_butt, 0, wx.CENTER|wx.LEFT|wx.RIGHT, 20)
         sizer.AddSpacer(10)
-        sizer.Add(donate_butt, 0, wx.CENTER|wx.LEFT|wx.RIGHT|wx.BOTTOM, 20)
+        sizer.Add(donate_butt, 0, wx.CENTER|wx.LEFT|wx.RIGHT, 20)
+        sizer.AddSpacer(10)
+        sizer.Add(cite_butt, 0, wx.CENTER|wx.LEFT|wx.RIGHT|wx.BOTTOM, 20)
         
         sizer.Fit(panel)
         return sizer
