@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -129,11 +129,9 @@ class panelCalibration(wx.MiniFrame):
         self.unitsPpm_radio.Bind(wx.EVT_RADIOBUTTON, self.onUnitsChanged)
         
         self.assign_butt = wx.Button(panel, -1, "Assign", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.assign_butt.SetFont(wx.SMALL_FONT)
         self.assign_butt.Bind(wx.EVT_BUTTON, self.onAssign)
         
         self.apply_butt = wx.Button(panel, -1, "Apply", size=(100, mwx.SMALL_BUTTON_HEIGHT))
-        self.apply_butt.SetFont(wx.SMALL_FONT)
         self.apply_butt.Bind(wx.EVT_BUTTON, self.onApply)
         self.apply_butt.Disable()
         
@@ -177,9 +175,9 @@ class panelCalibration(wx.MiniFrame):
         choices = libs.references.keys()
         choices.sort()
         choices.insert(0,'Reference lists')
-        self.references_combo = wx.ComboBox(ctrlPanel, -1, choices=choices, size=(250, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.references_combo.Select(0)
-        self.references_combo.Bind(wx.EVT_COMBOBOX, self.onReferencesSelected)
+        self.references_choice = wx.Choice(ctrlPanel, -1, choices=choices, size=(250, mwx.SMALL_CHOICE_HEIGHT))
+        self.references_choice.Select(0)
+        self.references_choice.Bind(wx.EVT_CHOICE, self.onReferencesSelected)
         
         tolerance_label = wx.StaticText(ctrlPanel, -1, "Tolerance:")
         tolerance_label.SetFont(wx.SMALL_FONT)
@@ -198,7 +196,7 @@ class panelCalibration(wx.MiniFrame):
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
         sizer.Add(references_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.references_combo, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.references_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
         sizer.Add(tolerance_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.tolerance_value, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
@@ -259,6 +257,7 @@ class panelCalibration(wx.MiniFrame):
         self.errorCanvas.setProperties(yLabel='error')
         self.errorCanvas.setProperties(showZero=True)
         self.errorCanvas.setProperties(showGrid=True)
+        self.errorCanvas.setProperties(showMinorTicks=False)
         self.errorCanvas.setProperties(showLegend=True)
         self.errorCanvas.setProperties(showPosBar=True)
         self.errorCanvas.setProperties(posBarHeight=6)
@@ -431,7 +430,7 @@ class panelCalibration(wx.MiniFrame):
         self.apply_butt.Enable(False)
         
         # get references
-        group = self.references_combo.GetValue()
+        group = self.references_choice.GetStringSelection()
         if group and group in libs.references:
             self.currentReferences = []
             for item in libs.references[group]:
@@ -449,13 +448,13 @@ class panelCalibration(wx.MiniFrame):
         
         # enable statistical calibration
         if self.statCalibration_check.GetValue():
-            self.references_combo.Enable(False)
+            self.references_choice.Enable(False)
             self.tolerance_value.Enable(False)
             self.onAssign()
             
         # disable statistical calibration
         else:
-            self.references_combo.Enable(True)
+            self.references_choice.Enable(True)
             self.tolerance_value.Enable(True)
             self.onReferencesSelected()
     # ----
@@ -551,7 +550,7 @@ class panelCalibration(wx.MiniFrame):
         self.apply_butt.Enable(False)
         
         # do processing
-        self.processing = threading.Thread(target=self.applyCalibration, kwargs={'fce':self.currentCalibration[0], 'params':self.currentCalibration[1]})
+        self.processing = threading.Thread(target=self.applyCalibration, kwargs={'fn':self.currentCalibration[0], 'params':self.currentCalibration[1]})
         self.processing.start()
         
         # pulse gauge while working
@@ -570,7 +569,7 @@ class panelCalibration(wx.MiniFrame):
         self.updateErrorPlot()
         
         # update document
-        self.parent.onDocumentChanged(('spectrum', 'notations'))
+        self.parent.onDocumentChanged(items=('spectrum', 'notations'))
         
         # hide processing gauge
         self.onProcessing(False)
@@ -704,7 +703,7 @@ class panelCalibration(wx.MiniFrame):
         # make peaklist
         if self.currentDocument and self.currentDocument.spectrum.peaklist:
             peaks = self.makeCurrentPeaklist(minY, maxY)
-            obj = mspy.plot.spectrum(mspy.scan(peaks=peaks), tickColour=(170,170,170), showLabels=False)
+            obj = mspy.plot.spectrum(mspy.scan(peaklist=peaks), tickColour=(170,170,170), showLabels=False)
             container.append(obj)
         
         # set units
@@ -738,9 +737,9 @@ class panelCalibration(wx.MiniFrame):
             # set GUI
             self.onToolSelected(tool='references')
             self.statCalibration_check.SetValue(False)
-            self.references_combo.Enable(True)
+            self.references_choice.Enable(True)
             self.tolerance_value.Enable(True)
-            self.references_combo.Select(0)
+            self.references_choice.Select(0)
             
             # set references
             self.currentReferences = []
@@ -872,23 +871,23 @@ class panelCalibration(wx.MiniFrame):
     # ----
     
     
-    def applyCalibration(self, fce, params):
+    def applyCalibration(self, fn, params):
         """Calibrate document."""
         
         # backup data
         self.currentDocument.backup(('spectrum', 'notations'))
         
         # recalibrate spectrum
-        self.currentDocument.spectrum.applyCalibration(fce, params)
+        self.currentDocument.spectrum.recalibrate(fn, params)
         
         # recalibrate annotations
         for annotation in self.currentDocument.annotations:
-            annotation.mz = fce(params, annotation.mz)
+            annotation.mz = fn(params, annotation.mz)
         
         # recalibrate matches
         for sequence in self.currentDocument.sequences:
             for match in sequence.matches:
-                match.mz = fce(params, match.mz)
+                match.mz = fn(params, match.mz)
     # ----
     
     
@@ -901,14 +900,14 @@ class panelCalibration(wx.MiniFrame):
         
         # init params
         step = (maxX-minX)/100.
-        fce = self.currentCalibration[0]
+        fn = self.currentCalibration[0]
         params = self.currentCalibration[1]
         
         # make points in Da
         points = []
         for x in range(100):
             mz = minX+step*x
-            error = mspy.delta(mz, fce(params, mz), config.calibration['units'])
+            error = mspy.delta(mz, fn(params, mz), config.calibration['units'])
             points.append((mz, error))
         
         return points
