@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -104,7 +104,6 @@ class panelDocumentExport(wx.MiniFrame):
         
         # make controls
         self.export_butt = wx.Button(panel, -1, "Export", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.export_butt.SetFont(wx.SMALL_FONT)
         self.export_butt.Bind(wx.EVT_BUTTON, self.onExport)
         
         # pack elements
@@ -139,21 +138,21 @@ class panelDocumentExport(wx.MiniFrame):
         imageHeight_label = wx.StaticText(panel, -1, "Height:")
         self.imageHeight_value = wx.TextCtrl(panel, -1, str(config.export['imageHeight']), size=(140, -1), validator=mwx.validator('floatPos'))
         
-        self.imageUnits_combo = wx.ComboBox(panel, -1, choices=['cm', 'in', 'px'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.imageUnits_combo.SetValue(config.export['imageUnits'])
+        self.imageUnits_choice = wx.Choice(panel, -1, choices=['cm', 'in', 'px'], size=(60, mwx.CHOICE_HEIGHT))
+        self.imageUnits_choice.SetStringSelection(config.export['imageUnits'])
         
         imageFormat_label = wx.StaticText(panel, -1, "Format:")
-        self.imageFormat_combo = wx.ComboBox(panel, -1, choices=['PNG', 'TIFF', 'JPEG'], size=(140, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.imageFormat_combo.SetValue(config.export['imageFormat'])
+        self.imageFormat_choice = wx.Choice(panel, -1, choices=['PNG', 'TIFF', 'JPEG'], size=(140, mwx.CHOICE_HEIGHT))
+        self.imageFormat_choice.SetStringSelection(config.export['imageFormat'])
         
         imageResolution_label = wx.StaticText(panel, -1, "Resolution:")
         imageResolutionUnits_label = wx.StaticText(panel, -1, "dpi")
         choices = ['72', '150', '200', '300', '600']
-        self.imageResolution_combo = wx.ComboBox(panel, -1, choices=choices, size=(140, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.imageResolution_combo.Select(0)
+        self.imageResolution_choice = wx.Choice(panel, -1, choices=choices, size=(140, mwx.CHOICE_HEIGHT))
+        self.imageResolution_choice.Select(0)
         if str(config.export['imageResolution']) in choices:
-            self.imageResolution_combo.Select(choices.index(str(config.export['imageResolution'])))
-        self.imageResolution_combo.Bind(wx.EVT_COMBOBOX, self.onImageResolutionChanged)
+            self.imageResolution_choice.Select(choices.index(str(config.export['imageResolution'])))
+        self.imageResolution_choice.Bind(wx.EVT_CHOICE, self.onImageResolutionChanged)
         
         imageFontsScale_label = wx.StaticText(panel, -1, "Font scale:")
         self.imageFontsScale_slider = wx.Slider(panel, -1, config.export['imageFontsScale'], 1, 10, size=(140, -1), style=mwx.SLIDER_STYLE)
@@ -167,18 +166,18 @@ class panelDocumentExport(wx.MiniFrame):
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         grid.Add(imageWidth_label, (0,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.imageWidth_value, (0,1), flag=wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.imageUnits_combo, (0,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT)
+        grid.Add(self.imageUnits_choice, (0,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT)
         grid.Add(imageHeight_label, (1,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.imageHeight_value, (1,1), flag=wx.ALIGN_CENTER_VERTICAL)
         grid.Add(imageResolution_label, (2,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid.Add(self.imageResolution_combo, (2,1), flag=wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.imageResolution_choice, (2,1), flag=wx.ALIGN_CENTER_VERTICAL)
         grid.Add(imageResolutionUnits_label, (2,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT)
         grid.Add(imageFontsScale_label, (3,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.imageFontsScale_slider, (3,1), flag=wx.ALIGN_CENTER_VERTICAL)
         grid.Add(imageDrawingsScale_label, (4,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.imageDrawingsScale_slider, (4,1), flag=wx.ALIGN_CENTER_VERTICAL)
         grid.Add(imageFormat_label, (5,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid.Add(self.imageFormat_combo, (5,1), flag=wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.imageFormat_choice, (5,1), flag=wx.ALIGN_CENTER_VERTICAL)
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -231,19 +230,19 @@ class panelDocumentExport(wx.MiniFrame):
         self.peaklistColumnGroup_check.SetValue(config.export['peaklistColumns'].count('group'))
         
         peaklistSelect_label = wx.StaticText(panel, -1, "Export:")
-        self.peaklistSelect_combo = wx.ComboBox(panel, -1, choices=['All Peaks', 'Selected Peaks'], size=(200, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.peaklistSelect_combo.Select(0)
+        self.peaklistSelect_choice = wx.Choice(panel, -1, choices=['All Peaks', 'Selected Peaks'], size=(200, mwx.CHOICE_HEIGHT))
+        self.peaklistSelect_choice.Select(0)
         
         peaklistFormat_label = wx.StaticText(panel, -1, "Format:")
-        self.peaklistFormat_combo = wx.ComboBox(panel, -1, choices=['ASCII', 'MGF'], size=(200, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.peaklistFormat_combo.SetValue(config.export['peaklistFormat'])
-        self.peaklistFormat_combo.Bind(wx.EVT_COMBOBOX, self.onPeaklistFormatChanged)
+        self.peaklistFormat_choice = wx.Choice(panel, -1, choices=['ASCII', 'MGF'], size=(200, mwx.CHOICE_HEIGHT))
+        self.peaklistFormat_choice.SetStringSelection(config.export['peaklistFormat'])
+        self.peaklistFormat_choice.Bind(wx.EVT_CHOICE, self.onPeaklistFormatChanged)
         
         peaklistSeparator_label = wx.StaticText(panel, -1, "Separator:")
-        self.peaklistSeparator_combo = wx.ComboBox(panel, -1, choices=['Comma', 'Semicolon', 'Tab'], size=(200, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.peaklistSeparator_combo.SetValue(config.export['peaklistSeparator'])
+        self.peaklistSeparator_choice = wx.Choice(panel, -1, choices=['Comma', 'Semicolon', 'Tab'], size=(200, mwx.CHOICE_HEIGHT))
+        self.peaklistSeparator_choice.SetStringSelection(config.export['peaklistSeparator'])
         choices = {',':0, ';':1, 'tab':2}
-        self.peaklistSeparator_combo.Select(choices[config.export['peaklistSeparator']])
+        self.peaklistSeparator_choice.Select(choices[config.export['peaklistSeparator']])
         
         self.onPeaklistFormatChanged()
         
@@ -263,11 +262,11 @@ class panelDocumentExport(wx.MiniFrame):
         
         grid2 = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         grid2.Add(peaklistSelect_label, (0,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid2.Add(self.peaklistSelect_combo, (0,1))
+        grid2.Add(self.peaklistSelect_choice, (0,1))
         grid2.Add(peaklistFormat_label, (1,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid2.Add(self.peaklistFormat_combo, (1,1))
+        grid2.Add(self.peaklistFormat_choice, (1,1))
         grid2.Add(peaklistSeparator_label, (2,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid2.Add(self.peaklistSeparator_combo, (2,1))
+        grid2.Add(self.peaklistSeparator_choice, (2,1))
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid1, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -288,21 +287,21 @@ class panelDocumentExport(wx.MiniFrame):
         
         # make elements
         spectrumRange_label = wx.StaticText(panel, -1, "Range:")
-        self.spectrumRange_combo = wx.ComboBox(panel, -1, choices=['Full Spectrum', 'Current View'], size=(130, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.spectrumRange_combo.Select(0)
+        self.spectrumRange_choice = wx.Choice(panel, -1, choices=['Full Spectrum', 'Current View'], size=(130, mwx.CHOICE_HEIGHT))
+        self.spectrumRange_choice.Select(0)
         
         spectrumSeparator_label = wx.StaticText(panel, -1, "Separator:")
-        self.spectrumSeparator_combo = wx.ComboBox(panel, -1, choices=['Comma', 'Semicolon', 'Tab'], size=(130, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.spectrumSeparator_combo.SetValue(config.export['spectrumSeparator'])
+        self.spectrumSeparator_choice = wx.Choice(panel, -1, choices=['Comma', 'Semicolon', 'Tab'], size=(130, mwx.CHOICE_HEIGHT))
+        self.spectrumSeparator_choice.SetStringSelection(config.export['spectrumSeparator'])
         choices = {',':0, ';':1, 'tab':2}
-        self.spectrumSeparator_combo.Select(choices[config.export['spectrumSeparator']])
+        self.spectrumSeparator_choice.Select(choices[config.export['spectrumSeparator']])
         
         # pack elements
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         grid.Add(spectrumRange_label, (0,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid.Add(self.spectrumRange_combo, (0,1))
+        grid.Add(self.spectrumRange_choice, (0,1))
         grid.Add(spectrumSeparator_label, (1,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid.Add(self.spectrumSeparator_combo, (1,1))
+        grid.Add(self.spectrumSeparator_choice, (1,1))
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -424,7 +423,7 @@ class panelDocumentExport(wx.MiniFrame):
         """Get new image resolution."""
         
         # get resolution
-        resolution = int(self.imageResolution_combo.GetValue())
+        resolution = int(self.imageResolution_choice.GetStringSelection())
         
         # set scales
         if resolution == 72:
@@ -449,7 +448,7 @@ class panelDocumentExport(wx.MiniFrame):
         """Get new peaklist format."""
         
         # get format
-        config.export['peaklistFormat'] = self.peaklistFormat_combo.GetValue()
+        config.export['peaklistFormat'] = self.peaklistFormat_choice.GetStringSelection()
         
         # enable/disable columns and separator
         enable = True
@@ -467,7 +466,7 @@ class panelDocumentExport(wx.MiniFrame):
         self.peaklistColumnFwhm_check.Enable(enable)
         self.peaklistColumnResol_check.Enable(enable)
         self.peaklistColumnGroup_check.Enable(enable)
-        self.peaklistSeparator_combo.Enable(enable)
+        self.peaklistSeparator_choice.Enable(enable)
     # ----
     
     
@@ -615,9 +614,9 @@ class panelDocumentExport(wx.MiniFrame):
             # image
             config.export['imageWidth'] = float(self.imageWidth_value.GetValue())
             config.export['imageHeight'] = float(self.imageHeight_value.GetValue())
-            config.export['imageUnits'] = self.imageUnits_combo.GetValue()
-            config.export['imageFormat'] = self.imageFormat_combo.GetValue()
-            config.export['imageResolution'] = int(self.imageResolution_combo.GetValue())
+            config.export['imageUnits'] = self.imageUnits_choice.GetStringSelection()
+            config.export['imageFormat'] = self.imageFormat_choice.GetStringSelection()
+            config.export['imageResolution'] = int(self.imageResolution_choice.GetStringSelection())
             config.export['imageFontsScale'] = int(self.imageFontsScale_slider.GetValue())
             config.export['imageDrawingsScale'] = int(self.imageDrawingsScale_slider.GetValue())
             
@@ -647,11 +646,11 @@ class panelDocumentExport(wx.MiniFrame):
                 config.export['peaklistColumns'].append('group')
             
             choices = {'Comma':',', 'Semicolon':';', 'Tab':'tab'}
-            config.export['peaklistSeparator'] = choices[self.peaklistSeparator_combo.GetValue()]
+            config.export['peaklistSeparator'] = choices[self.peaklistSeparator_choice.GetStringSelection()]
             
             # spectrum data
             choices = {'Comma':',', 'Semicolon':';', 'Tab':'tab'}
-            config.export['spectrumSeparator'] = choices[self.spectrumSeparator_combo.GetValue()]
+            config.export['spectrumSeparator'] = choices[self.spectrumSeparator_choice.GetStringSelection()]
         
         # ring error bell if error
         except:
@@ -717,7 +716,7 @@ class panelDocumentExport(wx.MiniFrame):
         
         # get peaklist
         selection = {'All Peaks':'', 'Selected Peaks':'S'}
-        filters = selection[self.peaklistSelect_combo.GetValue()]
+        filters = selection[self.peaklistSelect_choice.GetStringSelection()]
         peaklist = self.parent.getCurrentPeaklist(filters)
         
         # check peaklist
@@ -784,9 +783,9 @@ class panelDocumentExport(wx.MiniFrame):
         """Export spectrum data."""
         
         # get spectrum
-        if self.spectrumRange_combo.GetValue() == 'Full Spectrum':
+        if self.spectrumRange_choice.GetStringSelection() == 'Full Spectrum':
             spectrum = self.parent.getCurrentSpectrumPoints()
-        elif self.spectrumRange_combo.GetValue() == 'Current View':
+        elif self.spectrumRange_choice.GetStringSelection() == 'Current View':
             spectrum = self.parent.getCurrentSpectrumPoints(currentView=True)
         
         # check spectrum
