@@ -277,7 +277,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         """Make results list."""
         
         # init results list
-        self.resultsList = mwx.sortListCtrl(panel, -1, size=(171, -1), style=mwx.LISTCTRL_STYLE_MULTI)
+        self.resultsList = mwx.sortListCtrl(panel, -1, size=(171, 350), style=mwx.LISTCTRL_STYLE_MULTI)
         self.resultsList.SetFont(wx.SMALL_FONT)
         self.resultsList.setAltColour(mwx.LISTCTRL_ALTCOLOUR)
         self.resultsList.Bind(wx.EVT_KEY_DOWN, self.onListKey)
@@ -352,10 +352,12 @@ class panelEnvelopeFit(wx.MiniFrame):
             mspy.start()
         
         # fit layout
+        self.spectrumCanvas.SetMinSize(self.spectrumCanvas.GetSize())
         self.Layout()
         self.mainSizer.Fit(self)
         try: wx.Yield()
         except: pass
+        self.spectrumCanvas.SetMinSize((-1,-1))
     # ----
     
     
@@ -425,6 +427,12 @@ class panelEnvelopeFit(wx.MiniFrame):
         while self.processing and self.processing.isAlive():
             self.gauge.pulse()
         
+        # check error
+        error = False
+        if self.currentFit is False:
+            self.currentFit = None
+            error = True
+        
         # update gui
         self.updateAverageLabel()
         self.updateSpectrumCanvas()
@@ -435,9 +443,9 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.calculate_butt.Enable(True)
         
         # check errors
-        if self.currentFit != None and self.currentFit.error == 1:
+        if error:
             wx.Bell()
-            dlg = mwx.dlgMessage(self, title="No data to fit.", message="There are no data in relevant mass range. Please check\nyour specified formula and charge.")
+            dlg = mwx.dlgMessage(self, title="No data to fit.", message="There are no data in relevant mass range. Please check\nspecified formula and charge.")
             dlg.ShowModal()
             dlg.Destroy()
     # ----
@@ -543,9 +551,8 @@ class panelEnvelopeFit(wx.MiniFrame):
         
         # get label
         label = "Average X: "
-        if self.currentFit != None and not self.currentFit.error:
-            label += '%0.2f' % (self.currentFit.average)
-            #label += '%0.2f (%s%0.2f)' % (self.currentFit.average, unichr(177), self.currentFit.std)
+        if self.currentFit != None:
+            label += '%0.1f' % (self.currentFit.average)
         
         # set label
         self.average_label.SetLabel(label)
@@ -587,22 +594,28 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.spectrumContainer.empty()
         
         # check fit
-        if self.currentFit == None or self.currentFit.error:
+        if self.currentFit == None:
             self.spectrumCanvas.draw(self.spectrumContainer)
             self.parent.updateTmpSpectrum(None)
             return
         
+        # get data
+        spectrum = self.currentFit.spectrum
+        data = self.currentFit.data
+        model = self.currentFit.model
+        envelope = self.currentFit.envelope()
+        
         # show results
-        self.spectrumContainer.append(mspy.plot.points(self.currentFit.spectrum, legend='measured', showPoints=False, exactFit=True, lineColour=(16, 71, 185)))
-        self.spectrumContainer.append(mspy.plot.points(self.currentFit.envelope(), legend='model', showPoints=False, exactFit=True, lineColour=(241,144,0)))
-        self.spectrumContainer.append(mspy.plot.points(self.currentFit.data, legend='', showLines=False, pointColour=(16, 71, 185)))
-        self.spectrumContainer.append(mspy.plot.points(self.currentFit.model, legend='', showLines=False, pointColour=(241,144,0)))
+        self.spectrumContainer.append(mspy.plot.points(spectrum, legend='measured', showPoints=False, exactFit=True, lineColour=(16, 71, 185)))
+        self.spectrumContainer.append(mspy.plot.points(envelope, legend='model', showPoints=False, exactFit=True, lineColour=(241,144,0)))
+        self.spectrumContainer.append(mspy.plot.points(data, legend='', showLines=False, pointColour=(16, 71, 185)))
+        self.spectrumContainer.append(mspy.plot.points(model, legend='', showLines=False, pointColour=(241,144,0)))
         
         # draw container
         self.spectrumCanvas.draw(self.spectrumContainer)
         
         # update spectrum overlay
-        self.parent.updateTmpSpectrum(self.currentFit.envelope())
+        self.parent.updateTmpSpectrum(envelope)
     # ----
     
     
@@ -610,7 +623,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         """Update results list."""
         
         # make data map
-        if self.currentFit == None or self.currentFit.error:
+        if self.currentFit == None:
             data = []
         else:
             data = self.currentFit.ncomposition.items()
@@ -645,18 +658,22 @@ class panelEnvelopeFit(wx.MiniFrame):
         # run task
         try:
             
+            # get scales
+            scales = [(x) for x in range(config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']+1)]
+            
             # init module
             self.currentFit = mspy.envfit(
                 formula = self.currentCompound.formula(),
                 charge = config.envelopeFit['charge'],
-                scale = (config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']),
+                scales = scales,
                 loss = config.envelopeFit['loss'],
-                gain = config.envelopeFit['gain']
+                gain = config.envelopeFit['gain'],
+                peakShape = config.envelopeFit['peakShape']
             )
             
             # fit data to peaklist
             if config.envelopeFit['fit'] == 'peaklist':
-                self.currentFit.topeaklist(
+                success = self.currentFit.topeaklist(
                     peaklist = self.currentDocument.spectrum.peaklist,
                     fwhm = config.envelopeFit['fwhm'],
                     forceFwhm = config.envelopeFit['forceFwhm'],
@@ -680,7 +697,7 @@ class panelEnvelopeFit(wx.MiniFrame):
                 )
                 
                 # fit data to spectrum
-                self.currentFit.tospectrum(
+                success = self.currentFit.tospectrum(
                     signal = self.currentDocument.spectrum.profile,
                     fwhm = config.envelopeFit['fwhm'],
                     forceFwhm = config.envelopeFit['forceFwhm'],
@@ -688,9 +705,13 @@ class panelEnvelopeFit(wx.MiniFrame):
                     iterLimit =  100*config.envelopeFit['scaleMax'],
                     pickingHeight = config.processing['peakpicking']['pickingHeight'],
                     relThreshold = config.envelopeFit['relThreshold'],
-                    baselineData = baseline
+                    baseline = baseline
                 )
             
+            # erase if not success
+            if not success:
+                self.currentFit = False
+            
         # task canceled
         except mspy.ForceQuit:
             self.currentFit = None
