@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -86,28 +86,25 @@ class panelMassFilter(wx.MiniFrame):
         choices = libs.references.keys()
         choices.sort()
         choices.insert(0,'Reference lists')
-        self.references_combo = wx.ComboBox(panel, -1, choices=choices, size=(200, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.references_combo.Select(0)
-        self.references_combo.Bind(wx.EVT_COMBOBOX, self.onReferencesSelected)
+        self.references_choice = wx.Choice(panel, -1, choices=choices, size=(200, mwx.SMALL_CHOICE_HEIGHT))
+        self.references_choice.Select(0)
+        self.references_choice.Bind(wx.EVT_CHOICE, self.onReferencesSelected)
         
         # make buttons
         self.match_butt = wx.Button(panel, -1, "Match", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.match_butt.SetFont(wx.SMALL_FONT)
         self.match_butt.Bind(wx.EVT_BUTTON, self.onMatch)
         
         self.annotate_butt = wx.Button(panel, -1, "Annotate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.annotate_butt.SetFont(wx.SMALL_FONT)
         self.annotate_butt.Bind(wx.EVT_BUTTON, self.onAnnotate)
         
         self.remove_butt = wx.Button(panel, -1, "Remove", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.remove_butt.SetFont(wx.SMALL_FONT)
         self.remove_butt.Bind(wx.EVT_BUTTON, self.onRemove)
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
         sizer.Add(references_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.references_combo, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.references_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.match_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 10)
@@ -249,7 +246,7 @@ class panelMassFilter(wx.MiniFrame):
             self.matchPanel.clear()
         
         # get references
-        group = self.references_combo.GetValue()
+        group = self.references_choice.GetStringSelection()
         if group and group in libs.references:
             self.currentReferences = []
             for item in libs.references[group]:
@@ -316,7 +313,7 @@ class panelMassFilter(wx.MiniFrame):
             self.currentDocument.backup(('annotations'))
             self.currentDocument.annotations += annotations
             self.currentDocument.sortAnnotations()
-            self.parent.onDocumentChanged(('annotations'))
+            self.parent.onDocumentChanged(items=('annotations'))
     # ----
     
     
@@ -344,7 +341,7 @@ class panelMassFilter(wx.MiniFrame):
         if indexes:
             self.currentDocument.backup(('spectrum'))
             self.currentDocument.spectrum.peaklist.delete(indexes)
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
