@@ -534,6 +534,15 @@ class panelMassToFormula(wx.MiniFrame):
             wx.Bell()
             return
         
+        # check mass limit
+        if not self.checkMassLimit():
+            wx.Bell()
+            message = "Neutral mass of your specified ion is too high (%.0f Da max)." % config.massToFormula['massLimit']
+            dlg = mwx.dlgMessage(self, title="Neutral mass is too high.", message=message)
+            dlg.ShowModal()
+            dlg.Destroy()
+            return
+        
         # show processing gauge
         self.onProcessing(True)
         self.generate_butt.Enable(False)
@@ -554,7 +563,7 @@ class panelMassToFormula(wx.MiniFrame):
         self.generate_butt.Enable(True)
         
         # show limit warning
-        if self.currentFormulae and len(self.currentFormulae) == config.massToFormula['limit']:
+        if self.currentFormulae and len(self.currentFormulae) >= config.massToFormula['countLimit']:
             wx.Bell()
             dlg = mwx.dlgMessage(self, title="Maximum number of formulae reached.", message="The internal limit for number of formulae has been reached.\nPlease note that your formula could be missing.")
             dlg.ShowModal()
@@ -739,7 +748,7 @@ class panelMassToFormula(wx.MiniFrame):
                 composition = composition,
                 agentFormula = config.massToFormula['ionization'],
                 agentCharge = agentCharge,
-                limit = config.massToFormula['limit']
+                limit = config.massToFormula['countLimit']
             )
             
             # make compounds
@@ -1004,6 +1013,31 @@ class panelMassToFormula(wx.MiniFrame):
     # ----
     
     
+    def checkMassLimit(self):
+        """Check maximim neutral mass allowed."""
+        
+        # get agent charge
+        agentCharge = 1
+        if config.massToFormula['ionization'] == 'e':
+            agentCharge = -1
+        
+        # approximate CHNO composition from neutral mass
+        mass = mspy.mz(
+            mass = self.currentMass,
+            charge = 0,
+            currentCharge = config.massToFormula['charge'],
+            agentFormula = config.massToFormula['ionization'],
+            agentCharge = agentCharge
+        )
+        
+        # check mass limit
+        if mass <= config.massToFormula['massLimit']:
+            return True
+        
+        return False
+    # ----
+    
+    
     def _escape(self, text):
         """Clear special characters such as <> etc."""
         
