@@ -1924,17 +1924,17 @@ class panelProcessing(wx.MiniFrame):
         try:
             
             # get selected documents
-            selected = self.batchDocumentsList.getSelected()
-            if not selected:
-                return
+            documents = []
+            for x in self.batchDocumentsList.getSelected():
+                docIndex = self.batchDocumentsList.GetItemData(x)
+                documents.append(docIndex)
             
             # process selected documents
-            for x in selected:
+            for docIndex in documents:
                 
                 # select document
-                index = self.batchDocumentsList.GetItemData(selected[x])
-                self.currentDocument = self.parent.documents[index]
-                self.batchChanged.append(index)
+                self.currentDocument = self.parent.documents[docIndex]
+                self.batchChanged.append(docIndex)
                 
                 # backup document
                 self.currentDocument.backup(('spectrum', 'notations'))
