@@ -44,7 +44,7 @@ class panelSpectrum(wx.Panel):
         self.currentTmpSpectrum = None
         self.currentTmpSpectrumFlip = False
         self.currentNotationMarks = None
-        self.currentTool = 'measure'
+        self.currentTool = 'ruler'
         
         # init container
         self.container = mspy.plot.container([])
@@ -105,13 +105,12 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(showCurYPos=True)
         self.spectrumCanvas.setProperties(showCurCharge=True)
         self.spectrumCanvas.setProperties(showCurImage=config.spectrum['showCursorImage'])
-        self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(autoScaleY=config.spectrum['autoscale'])
         self.spectrumCanvas.setProperties(overlapLabels=config.spectrum['overlapLabels'])
+        self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
         self.spectrumCanvas.setProperties(distanceDigits=config.main['mzDigits'])
-        self.spectrumCanvas.setProperties(checkLimits=True)
         self.spectrumCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.spectrumCanvas.setProperties(reverseDrawing=True)
         
@@ -182,6 +181,10 @@ class panelSpectrum(wx.Panel):
         self.normalize_butt.Bind(wx.EVT_BUTTON, self.parent.onView)
         
         # make processing toolset
+        self.toolsRuler_butt = wx.BitmapButton(panel, ID_toolsRuler, images.lib['spectrumRulerOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
+        self.toolsRuler_butt.SetToolTip(wx.ToolTip("Spectrum ruler"))
+        self.toolsRuler_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
+        
         self.toolsLabelPeak_butt = wx.BitmapButton(panel, ID_toolsLabelPeak, images.lib['spectrumLabelPeakOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
         self.toolsLabelPeak_butt.SetToolTip(wx.ToolTip("Label peak"))
         self.toolsLabelPeak_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
@@ -198,10 +201,6 @@ class panelSpectrum(wx.Panel):
         self.toolsDeleteLabel_butt.SetToolTip(wx.ToolTip("Delete label"))
         self.toolsDeleteLabel_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
         
-        self.toolsMeasure_butt = wx.BitmapButton(panel, ID_toolsMeasure, images.lib['spectrumMeasureOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
-        self.toolsMeasure_butt.SetToolTip(wx.ToolTip("Spectrum ruler"))
-        self.toolsMeasure_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
-        
         self.toolsOffset_butt = wx.BitmapButton(panel, ID_toolsOffset, images.lib['spectrumOffsetOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
         self.toolsOffset_butt.SetToolTip(wx.ToolTip("Offset spectrum"))
         self.toolsOffset_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
@@ -224,11 +223,11 @@ class panelSpectrum(wx.Panel):
         sizer.Add(self.autoscale_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.normalize_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.AddSpacer(20)
+        sizer.Add(self.toolsRuler_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.toolsLabelPeak_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.toolsLabelPoint_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.toolsLabelEnvelope_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.toolsDeleteLabel_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
-        sizer.Add(self.toolsMeasure_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.Add(self.toolsOffset_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.LEFT, mwx.BUTTON_SIZE_CORRECTION)
         sizer.AddSpacer(20)
         sizer.Add(self.cursorInfo, 0, wx.ALIGN_CENTER_VERTICAL, 0)
@@ -268,7 +267,7 @@ class panelSpectrum(wx.Panel):
         # check document
         if self.currentDocument == None:
             evt.Skip()
-            if self.currentTool not in ('measure'):
+            if self.currentTool not in ('ruler'):
                 wx.Bell()
             return
         
@@ -349,7 +348,7 @@ class panelSpectrum(wx.Panel):
         """Set items to show in cursor info."""
         
         # only while active spectrum ruler
-        if self.currentTool != 'measure':
+        if self.currentTool != 'ruler':
             return
         
         # popup menu
@@ -358,7 +357,7 @@ class panelSpectrum(wx.Panel):
         menu.Append(ID_viewSpectrumRulerDist, "Distance", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerPpm, "ppm", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerZ, "Charge", "", wx.ITEM_CHECK)
-        menu.Append(ID_viewSpectrumRulerMass, "Mass", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerCursorMass, "Mass", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerArea, "Area", "", wx.ITEM_CHECK)
         
         # set values
@@ -366,7 +365,7 @@ class panelSpectrum(wx.Panel):
         menu.Check(ID_viewSpectrumRulerDist, bool('dist' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerPpm, bool('ppm' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerZ, bool('z' in config.main['cursorInfo']))
-        menu.Check(ID_viewSpectrumRulerMass, bool('mass' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerCursorMass, bool('mass' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerArea, bool('area' in config.main['cursorInfo']))
         
         # set events
@@ -374,7 +373,7 @@ class panelSpectrum(wx.Panel):
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerDist)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerPpm)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerZ)
-        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerMass)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerCursorMass)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerArea)
         
         self.PopupMenu(menu)
@@ -389,11 +388,11 @@ class panelSpectrum(wx.Panel):
         self.currentTool = tool
         
         # set icons off
+        self.toolsRuler_butt.SetBitmapLabel(images.lib['spectrumRulerOff'])
         self.toolsLabelPeak_butt.SetBitmapLabel(images.lib['spectrumLabelPeakOff'])
         self.toolsLabelPoint_butt.SetBitmapLabel(images.lib['spectrumLabelPointOff'])
         self.toolsLabelEnvelope_butt.SetBitmapLabel(images.lib['spectrumLabelEnvelopeOff'])
         self.toolsDeleteLabel_butt.SetBitmapLabel(images.lib['spectrumDeleteLabelOff'])
-        self.toolsMeasure_butt.SetBitmapLabel(images.lib['spectrumMeasureOff'])
         self.toolsOffset_butt.SetBitmapLabel(images.lib['spectrumOffsetOff'])
         
         # set cursor tracker
@@ -402,7 +401,13 @@ class panelSpectrum(wx.Panel):
             cursorTracker = 'cross'
         
         # set tool
-        if tool == 'labelpeak':
+        if tool == 'ruler':
+            self.toolsRuler_butt.SetBitmapLabel(images.lib['spectrumRulerOn'])
+            self.spectrumCanvas.setMFunction(cursorTracker)
+            self.spectrumCanvas.setLMBFunction('xDistance')
+            cursor = (wx.StockCursor(wx.CURSOR_ARROW), images.lib['cursorsCrossMeasure'])
+        
+        elif tool == 'labelpeak':
             self.toolsLabelPeak_butt.SetBitmapLabel(images.lib['spectrumLabelPeakOn'])
             self.spectrumCanvas.setMFunction(None)
             self.spectrumCanvas.setLMBFunction('range')
@@ -426,12 +431,6 @@ class panelSpectrum(wx.Panel):
             self.spectrumCanvas.setLMBFunction('rectangle')
             cursor = (images.lib['cursorsArrowDelete'], images.lib['cursorsArrowDelete'])
         
-        elif tool == 'measure':
-            self.toolsMeasure_butt.SetBitmapLabel(images.lib['spectrumMeasureOn'])
-            self.spectrumCanvas.setMFunction(cursorTracker)
-            self.spectrumCanvas.setLMBFunction('xDistance')
-            cursor = (wx.StockCursor(wx.CURSOR_ARROW), images.lib['cursorsCrossMeasure'])
-        
         elif tool == 'offset':
             self.toolsOffset_butt.SetBitmapLabel(images.lib['spectrumOffsetOn'])
             self.spectrumCanvas.setMFunction(cursorTracker)
@@ -534,6 +533,7 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
         self.spectrumCanvas.setProperties(distanceDigits=config.main['mzDigits'])
         self.spectrumCanvas.setProperties(overlapLabels=config.spectrum['overlapLabels'])
+        self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(autoScaleY=config.spectrum['autoscale'])
         self.spectrumCanvas.setProperties(showGel=config.spectrum['showGel'])
         self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
@@ -597,7 +597,7 @@ class panelSpectrum(wx.Panel):
         distFormat = '%0.' + `config.main['mzDigits']` + 'f'
         ppmFormat = '%0.' + `config.main['ppmDigits']` + 'f'
         areaFormat = '%0.' + `config.main['intDigits']` + 'f'
-        chargeFormat = '%0.1f'
+        chargeFormat = '%0.' + `config.main['chargeDigits']` + 'f'
         
         if position and abs(position[1]) > 10000:
             intFormat = '%.2e'
@@ -620,16 +620,20 @@ class panelSpectrum(wx.Panel):
             # get charge and mass from distance
             if distance[0] != 0 and abs(distance[0]) <= 2:
                 charge = abs(1/distance[0])
-                mass = mspy.mz(position[0], 0, round(charge)*polarity)
+                cmass = mspy.mz(position[0], 0, round(charge)*polarity)
+                pmass = mspy.mz(position[0]-distance[0], 0, round(charge)*polarity)
             elif distance[0] > 10:
                 charge = abs(((position[0]-distance[0]) - 1.00728) / distance[0])
-                mass = mspy.mz(position[0], 0, round(charge)*polarity)
+                cmass = mspy.mz(position[0], 0, round(charge)*polarity)
+                pmass = mspy.mz(position[0]-distance[0], 0, round(charge+1)*polarity)
             elif distance[0] < -10:
                 charge = abs((position[0] - 1.00728) / distance[0])
-                mass = mspy.mz(position[0], 0, round(charge+1)*polarity)
+                cmass = mspy.mz(position[0], 0, round(charge+1)*polarity)
+                pmass = mspy.mz(position[0]-distance[0], 0, round(charge)*polarity)
             else:
                 charge = 0
-                mass = 0
+                cmass = 0
+                pmass = 0
             
             if 'mz' in config.main['cursorInfo']:
                 format = 'm/z: %s   ' % mzFormat
@@ -648,12 +652,16 @@ class panelSpectrum(wx.Panel):
                     format = 'z: %s/%s   ' % (chargeFormat, chargeFormat)
                     label += format % ((charge+1)*polarity, charge*polarity)
                 else:
-                    format = 'z: %s   ' % chargeFormat
-                    label += format % (charge*polarity)
+                    format = 'z: %%d (%s)   ' % chargeFormat
+                    label += format % (round(charge*polarity), charge*polarity)
             
-            if 'mass' in config.main['cursorInfo'] and mass > 0:
-                format = 'mass: %s   ' % mzFormat
-                label += format % mass
+            if 'cmass' in config.main['cursorInfo'] and cmass > 0:
+                format = 'mass (c): %s   ' % mzFormat
+                label += format % cmass
+            
+            if 'pmass' in config.main['cursorInfo'] and pmass > 0:
+                format = 'mass (p): %s   ' % mzFormat
+                label += format % pmass
             
             if 'area' in config.main['cursorInfo'] and self.currentDocument != None:
                 area = self.documents[self.currentDocument].spectrum.area(
