@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -20,10 +20,10 @@ import re
 import os.path
 
 # load stopper
-from stopper import CHECK_FORCE_QUIT
+from mod_stopper import CHECK_FORCE_QUIT
 
-# register essential objects
-import objects
+# load objects
+import obj_sequence
 
 
 # compile basic patterns
@@ -48,7 +48,7 @@ class parseFASTA():
     # ----
     
     
-    def getSequences(self):
+    def sequences(self):
         """Get sequences from document."""
         
         # open document
@@ -75,7 +75,7 @@ class parseFASTA():
                 # store previous sequence
                 if reading:
                     try:
-                        sequence = objects.sequence(chain, title=title, accession=accession)
+                        sequence = obj_sequence.sequence(chain, title=title, accession=accession)
                         data.append(sequence)
                     except:
                         pass
@@ -113,7 +113,7 @@ class parseFASTA():
         # store last sequence
         if reading:
             try:
-                sequence = objects.sequence(chain, title=title, accession=accession)
+                sequence = obj_sequence.sequence(chain, title=title, accession=accession)
                 data.append(sequence)
             except:
                 pass
