@@ -12,11 +12,12 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
 import xml.sax
+import xml.dom.minidom
 import base64
 import zlib
 import struct
@@ -25,10 +26,12 @@ import numpy
 from copy import deepcopy
 
 # load stopper
-from stopper import CHECK_FORCE_QUIT
+from mod_stopper import CHECK_FORCE_QUIT
 
-# register essential objects
-import objects
+# load objects
+import obj_peak
+import obj_peaklist
+import obj_scan
 
 
 # PARSE mzML DATA
@@ -79,7 +82,7 @@ class parseMZML():
     # ----
     
     
-    def getInfo(self):
+    def info(self):
         """Get document info."""
         
         # get preloaded data if available
@@ -105,7 +108,7 @@ class parseMZML():
     # ----
     
     
-    def getScanlist(self):
+    def scanlist(self):
         """Get list of all scans in the document."""
         
         # use preloaded data if available
@@ -130,13 +133,19 @@ class parseMZML():
     # ----
     
     
-    def getScan(self, scanID=None):
+    def scan(self, scanID=None):
         """Get spectrum from document."""
         
         # use preloaded data if available
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
+        # faster loading of single-scan documents
+        elif scanID == None:
+            parser = singleScanParser(self.path)
+            parser.parse()
+            data = parser.data
+        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -168,10 +177,10 @@ class parseMZML():
         points = self._parsePoints(scanData)
         if scanData['spectrumType'] == 'discrete':
             for x, p in enumerate(points):
-                points[x] = objects.peak(p[0], p[1])
-            scan = objects.scan(peaks=objects.peaklist(points))
+                points[x] = obj_peak.peak(p[0], p[1])
+            scan = obj_scan.scan(peaklist=obj_peaklist.peaklist(points))
         else:
-            scan = objects.scan(points=points)
+            scan = obj_scan.scan(profile=points)
         
         # set metadata
         scan.title = scanData['title']
@@ -872,6 +881,172 @@ class runHandler(xml.sax.handler.ContentHandler):
     
     
 
+class singleScanParser():
+    """Faster loading of single-scan documents."""
+    
+    def __init__(self, path):
+        
+        self.path = path
+        self.data = None
+        self._parsedData = None
+    # ----
+    
+    
+    def parse(self):
+        """Parse document."""
+        
+        # read xml
+        try:
+            doc = file(self.path)
+            rawData = doc.read()
+            doc.close()
+            self._parsedData = xml.dom.minidom.parseString(rawData)
+        except:
+            self.data = None
+            return
+        
+        # init data
+        self.data = {
+                'title': '',
+                'scanNumber': None,
+                'parentScanNumber': None,
+                'msLevel': None,
+                'pointsCount': None,
+                'polarity': None,
+                'retentionTime': None,
+                'lowMZ': None,
+                'highMZ': None,
+                'basePeakMZ': None,
+                'basePeakIntensity': None,
+                'totIonCurrent': None,
+                'precursorMZ': None,
+                'precursorIntensity': None,
+                'precursorCharge': None,
+                'spectrumType': 'unknown',
+                
+                'mzData': None,
+                'mzPrecision': None,
+                'mzCompression': None,
+                'intData': None,
+                'intPrecision': None,
+                'intCompression': None,
+        }
+        
+        # parse xml
+        self.handleSpectrum()
+        self.handleMetadata()
+    # ----
+    
+    
+    def handleSpectrum(self):
+        """Get spectrum data."""
+        
+        # get spectrum type
+        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
+        for cvParamTag in cvParamTags:
+            if cvParamTag.getAttribute('name') == 'centroid spectrum':
+                self.data['spectrumType'] = 'discrete'
+            elif cvParamTag.getAttribute('name') == 'profile spectrum':
+                self.data['spectrumType'] = 'continuous'
+        
+        # get data
+        for binaryDataArrayTag in self._parsedData.getElementsByTagName('binaryDataArray'):
+                
+                tmpdata = {
+                    'dataType': '',
+                    'binaryData': '',
+                    'compression': None,
+                    'precision': 32,
+                }
+                
+                # get data
+                binary = binaryDataArrayTag.getElementsByTagName('binary')
+                for node in binary[0].childNodes:
+                    if node.nodeType == node.TEXT_NODE:
+                        tmpdata['binaryData'] += node.data
+                
+                # get params
+                for cvParamTag in binaryDataArrayTag.getElementsByTagName('cvParam'):
+                    if cvParamTag.getAttribute('name') == 'zlib compression':
+                        tmpdata['compression'] = 'zlib'
+                    if cvParamTag.getAttribute('name') == '64-bit float':
+                        tmpdata['precision'] = 64
+                    if cvParamTag.getAttribute('name') == '32-bit float':
+                        tmpdata['precision'] = 32
+                    if cvParamTag.getAttribute('name') == 'm/z array':
+                        tmpdata['dataType'] = 'm/z array'
+                    if cvParamTag.getAttribute('name') == 'intensity array':
+                        tmpdata['dataType'] = 'intensity array'
+                
+                # store data
+                if tmpdata['dataType'] == 'm/z array':
+                    self.data['mzData'] = tmpdata['binaryData']
+                    self.data['mzPrecision'] = tmpdata['precision']
+                    self.data['mzCompression'] = tmpdata['compression']
+                
+                elif tmpdata['dataType'] == 'intensity array':
+                    self.data['intData'] = tmpdata['binaryData']
+                    self.data['intPrecision'] = tmpdata['precision']
+                    self.data['intCompression'] = tmpdata['compression']
+    # ----
+    
+    
+    def handleMetadata(self):
+        """Get metadata."""
+        
+        # get cvParams
+        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
+        for cvParamTag in cvParamTags:
+            
+            paramName = cvParamTag.getAttribute('name')
+            paramValue = cvParamTag.getAttribute('value')
+            
+            # precursor
+            if paramName == 'selected ion m/z' and paramValue:
+                self.data['precursorMZ'] = float(paramValue)
+            elif paramName == 'intensity' and paramValue:
+                self.data['precursorIntensity'] = float(paramValue)
+            elif paramName == 'possible charge state' and paramValue:
+                self.data['precursorCharge'] = int(paramValue)
+            elif paramName == 'charge state' and paramValue:
+                self.data['precursorCharge'] = int(paramValue)
+            
+            # MS level
+            elif paramName == 'ms level' and paramValue:
+                self.data['msLevel'] = int(paramValue)
+            
+            # polarity
+            elif paramName == 'positive scan':
+                self.data['polarity'] = 1
+            elif paramName == 'negative scan':
+                self.data['polarity'] = -1
+            
+            # total ion current
+            elif paramName == 'total ion current' and paramValue:
+                self.data['totIonCurrent'] = float(paramValue)
+            
+            # base peak
+            elif paramName == 'base peak m/z' and paramValue:
+                self.data['basePeakMZ'] = float(paramValue)
+            elif paramName == 'base peak intensity' and paramValue:
+                self.data['basePeakIntensity'] = float(paramValue)
+            
+            # mass range
+            elif paramName == 'lowest observed m/z' and paramValue:
+                self.data['lowMZ'] = float(paramValue)
+            elif paramName == 'highest observed m/z' and paramValue:
+                self.data['highMZ'] = float(paramValue)
+            
+            # retention time
+            elif paramName == 'scan start time' and paramValue:
+                if cvParamTag.getAttribute('unitName') == 'minute':
+                    self.data['retentionTime'] = float(paramValue)*60
+                if cvParamTag.getAttribute('unitName') == 'second':
+                    self.data['retentionTime'] = float(paramValue)
+    # ----
+    
+    
+
 class stopParsing(Exception):
     """Exeption to stop parsing XML data."""
     pass
