@@ -1343,6 +1343,17 @@ class canvas(wx.Panel):
         # draw position
         dc.SetBrush(wx.Brush(self.properties['axisColour'], wx.SOLID))
         dc.DrawRectangle(x, y1, currWidth, height)
+        
+        # draw outside arrows
+        dc.SetPen(wx.TRANSPARENT_PEN)
+        dc.SetBrush(wx.Brush((255, 0, 0), wx.SOLID))
+        size = 6*self.printerScale['drawings']
+        if xAxis[1] < minX:
+            x = x1 - 2*self.printerScale['drawings']
+            dc.DrawPolygon([(x, y1), (x, y1+height), (x-size, y1+height/2)])
+        if xAxis[0] > maxX:
+            x = x2 + 2*self.printerScale['drawings']
+            dc.DrawPolygon([(x, y1), (x, y1+height), (x+size, y1+height/2)])
     # ----
     
     
@@ -1376,6 +1387,8 @@ class canvas(wx.Panel):
             y = y2
         if y+currHeight > y2:
             currHeight -= currHeight - (y2-y)
+        if y+currHeight < y1:
+            currHeight = 0
         
         # draw outline
         dc.SetBrush(wx.Brush(self.properties['plotColour'], wx.SOLID))
@@ -1384,6 +1397,17 @@ class canvas(wx.Panel):
         # draw position
         dc.SetBrush(wx.Brush(self.properties['axisColour'], wx.SOLID))
         dc.DrawRectangle(x1, y, width, currHeight)
+        
+        # draw outside arrows
+        dc.SetPen(wx.TRANSPARENT_PEN)
+        dc.SetBrush(wx.Brush((255, 0, 0), wx.SOLID))
+        size = 6*self.printerScale['drawings']
+        if yAxis[0] > maxY:
+            y = y1 - 2*self.printerScale['drawings']
+            dc.DrawPolygon([(x1, y), (x1+width, y), (x1+width/2, y-size)])
+        if yAxis[1] < minY:
+            y = y2 + 2*self.printerScale['drawings']
+            dc.DrawPolygon([(x1, y), (x1+width, y), (x1+width/2, y+size)])
     # ----
     
     
