@@ -324,7 +324,7 @@ class annotations:
         
         self.currentScale = (1., 1.)
         self.currentShift = (0., 0.)
-        self.normalization = (1., 0.)
+        self.normalization = 1.0
         
         # get new attributes
         for name, value in attr.items():
@@ -357,9 +357,9 @@ class annotations:
     # ----
     
     
-    def setNormalization(self, scale, shift):
+    def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
-        self.normalization = (scale, shift)
+        self.normalization = value
     # ----
     
     
@@ -405,8 +405,8 @@ class annotations:
         
         # apply normalization
         if self.properties['normalized']:
-            minXY[1] = (minXY[1] - self.normalization[1]) / self.normalization[0]
-            maxXY[1] = (maxXY[1] - self.normalization[1]) / self.normalization[0]
+            minXY[1] = minXY[1] / self.normalization
+            maxXY[1] = maxXY[1] / self.normalization
         
         # apply offset
         minXY[0] += self.properties['xOffset']
@@ -464,8 +464,7 @@ class annotations:
         
         # apply normalization
         if self.properties['normalized']:
-            yScale /= self.normalization[0]
-            yShift -= self.normalization[1] * yScale
+            yScale /= self.normalization
         
         # apply offset
         xShift += self.properties['xOffset'] * xScale
@@ -569,7 +568,7 @@ class annotations:
     def _normalization(self):
         """Calculate normalization constants."""
         
-        self.normalization = (1,0)
+        self.normalization = 1.0
         
         # check data
         if not len(self.points):
@@ -578,14 +577,8 @@ class annotations:
         # get range
         minXY, maxXY = self.pointsBox
         
-        # calculate scale and shift
-        scale = 1
-        shift = minXY[1]
-        rng = maxXY[1]
-        if rng:
-            scale = rng / (100 * (1 + shift / rng))
-        
-        self.normalization = (scale, shift)
+        # set normalization
+        self.normalization = maxXY[1] / 100.
     # ----
     
 
@@ -617,9 +610,9 @@ class points:
                             }
         
         
-        self.currentScale = (1, 1)
-        self.currentShift = (0, 0)
-        self.normalization = (1, 0)
+        self.currentScale = (1., 1.)
+        self.currentShift = (0., 0.)
+        self.normalization = 1.0
         
         # get new attributes
         for name, value in attr.items():
@@ -645,9 +638,9 @@ class points:
     # ----
     
     
-    def setNormalization(self, scale, shift):
+    def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
-        self.normalization = (scale, shift)
+        self.normalization = value
     # ----
     
     
@@ -684,8 +677,8 @@ class points:
         
         # apply normalization
         if self.properties['normalized']:
-            minXY[1] = (minXY[1] - self.normalization[1]) / self.normalization[0]
-            maxXY[1] = (maxXY[1] - self.normalization[1]) / self.normalization[0]
+            minXY[1] = minXY[1] / self.normalization
+            maxXY[1] = maxXY[1] / self.normalization
         
         # apply offset
         minXY[0] += self.properties['xOffset']
@@ -765,8 +758,7 @@ class points:
         
         # apply normalization
         if self.properties['normalized']:
-            yScale /= self.normalization[0]
-            yShift -= self.normalization[1] * yScale
+            yScale /= self.normalization
         
         # apply offset
         xShift += self.properties['xOffset'] * xScale
@@ -832,7 +824,7 @@ class points:
     def _normalization(self):
         """Calculate normalization constants."""
         
-        self.normalization = (1,0)
+        self.normalization = 1.0
         
         # check data
         if not len(self.points):
@@ -841,14 +833,8 @@ class points:
         # get range
         minXY, maxXY = self.pointsBox
         
-        # calculate scale and shift
-        scale = 1
-        shift = minXY[1]
-        rng = maxXY[1]
-        if rng:
-            scale = rng / (100 * (1 + shift / rng))
-        
-        self.normalization = (scale, shift)
+        # set normalization
+        self.normalization = maxXY[1] / 100.
     # ----
     
 
@@ -893,9 +879,9 @@ class spectrum:
                             'yOffsetDigits': 0,
                             }
         
-        self.currentScale = (1, 1)
-        self.currentShift = (0, 0)
-        self.normalization = (1, 0)
+        self.currentScale = (1., 1.)
+        self.currentShift = (0., 0.)
+        self.normalization = 1.0
         
         # get new attributes
         for name, value in attr.items():
@@ -930,9 +916,9 @@ class spectrum:
     # ----
     
     
-    def setNormalization(self, scale, shift):
+    def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
-        self.normalization = (scale, shift)
+        self.normalization = value
     # ----
     
     
@@ -1004,8 +990,8 @@ class spectrum:
         
         # apply normalization
         if self.properties['normalized']:
-            minXY[1] = (minXY[1] - self.normalization[1]) / self.normalization[0]
-            maxXY[1] = (maxXY[1] - self.normalization[1]) / self.normalization[0]
+            minXY[1] = minXY[1] / self.normalization
+            maxXY[1] = maxXY[1] / self.normalization
         
         # apply offset
         if not self.properties['normalized']:
@@ -1113,8 +1099,7 @@ class spectrum:
         
         # apply normalization
         if self.properties['normalized']:
-            yScale /= self.normalization[0]
-            yShift -= self.normalization[1] * yScale
+            yScale /= self.normalization
         
         # apply offset
         if not self.properties['normalized']:
@@ -1507,36 +1492,21 @@ class spectrum:
     def _normalization(self):
         """Calculate normalization constants."""
         
-        scale = 1
-        shift = 0
-        
-        # get range
-        if len(self.spectrumPoints):
-            spectrumMin, spectrumMax = self.spectrumBox
-        
-        if len(self.peaklistPoints):
-            peaklistMin, peaklistMax = self.peaklistBox
-        
-        # calculate scale and shift
+        # get range from points and peaklist
         if len(self.spectrumPoints) and len(self.peaklistPoints):
-            shift = min(spectrumMin[1], peaklistMin[2])
-            rng = max(spectrumMax[1], peaklistMax[1])
-            if rng:
-                scale = rng / (100 * (1 + shift / rng))
+            spectrumMinXY, spectrumMaxXY = self.spectrumBox
+            peaklistMinXY, peaklistMaxXY = self.peaklistBox
+            self.normalization = max(spectrumMaxXY[1], peaklistMaxXY[1]) / 100.
         
+        # get range from points only
         elif len(self.spectrumPoints):
-            shift = spectrumMin[1]
-            rng = spectrumMax[1]
-            if rng:
-                scale = rng / (100 * (1 + shift / rng))
+            minXY, maxXY = self.spectrumBox
+            self.normalization = maxXY[1] / 100.
         
+        # get range from peaklist only
         elif len(self.peaklistPoints):
-            shift = peaklistMin[2]
-            rng = peaklistMax[1]
-            if rng:
-                scale = rng / (100 * (1 + shift / rng))
-        
-        self.normalization = (scale, shift)
+            minXY, maxXY = self.peaklistBox
+            self.normalization = maxXY[1] / 100.
     # ----
     
     
