@@ -17,8 +17,9 @@ numpyInclude = numpy.get_include() + '/numpy'
 pythonInclude = sys.prefix + '/include'
 
 # make setup
-setup(name = 'calculations',
-    version = '0.1',
+setup(
+    name = 'calculations',
+    version = '1.0',
     author = "Martin Strohalm",
     maintainer = 'Martin Strohalm',
     description = "Fast calculations for mspy.",
